@@ -8,7 +8,7 @@ def test_main():
     runner = CliRunner()
     result = runner.invoke(main, ['tests/examples/2AP05.lp'])
 
-    assert '9 non dominated vectors found' in result.output
+    assert 'Non-dominated vectors found: 9' in result.output
 
     assert '(50, 24)' in result.output
     assert '(39, 28)' in result.output
